==> 2.4.2.tar.gz: cloudlog/application/language/german/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('Direkter Zugriff auf Skripte ist nicht erlaubt');

$lang['error_no_active_station_profile'] = 'Achtung: Du musst ein aktives Stationsprofil auswählen.';

$lang['notice_turn_the_radio_on'] = 'Du hast heute noch keine QSOs gemacht; Zeit, das Funkgerät einzuschalten!';

$lang['general_word_important'] = 'Wichtig';
$lang['general_word_info'] = 'Info';
$lang['general_word_choose_file'] = 'Datei wählen';

$lang['general_word_date'] = 'Datum';
$lang['general_word_time'] = 'Zeit';
$lang['general_word_datetime'] = 'Datum/Uhrzeit';
$lang['general_word_none'] = 'None';
$lang['general_word_name'] = 'Name';
$lang['general_word_location'] = 'Standort';
$lang['general_word_comment'] = 'Kommentar';
$lang['general_word_general'] = 'Allgemeines';
$lang['general_word_satellite'] = 'Satellit';
$lang['general_word_satellite_short'] = 'Sat';
$lang['general_word_notes'] = 'Notizen';
$lang['general_word_country'] = 'Land';

$lang['general_word_total'] = 'Gesamt';
$lang['general_word_year'] = 'Jahr';
$lang['general_word_month'] = 'Monat';

$lang['general_word_worked'] = 'Gearbeitet';
$lang['general_word_confirmed'] = 'Bestätigt';
$lang['general_word_needed'] = 'Benötigt';

$lang['general_word_no'] = 'Nein';
$lang['general_word_yes'] = 'Ja';
$lang['general_word_method'] = 'Methode';

$lang['general_word_sent'] = 'Gesendet';
$lang['general_word_received'] = 'Erhalten';
$lang['general_word_requested'] = 'Angefordert';
$lang['general_word_queued'] = 'In Warteschlange';
$lang['general_word_invalid_ignore'] = 'Ungültig (Ignorieren)';
$lang['general_word_qslcard'] = 'QSL Karte';
$lang['general_word_qslcard_management'] = 'QSL Verwaltung';
$lang['general_word_qslcards'] = 'QSL Karten';
$lang['general_word_qslcard_direct'] = 'Direkt';
$lang['general_word_qslcard_bureau'] = 'Büro';
$lang['general_word_qslcard_electronic'] = 'Elektronisch';
$lang['general_word_qslcard_via'] = 'Via';
$lang['general_word_eqslcards'] = 'eQSL Karten';
$lang['general_word_lotw'] = 'Logbook of the World';

$lang['general_edit_qso'] = 'QSO bearbeiten';
$lang['general_mark_qsl_rx_bureau'] = 'Markiere QSL erhalten (Büro)';
$lang['general_mark_qsl_rx_direct'] = 'Markiere QSL erhalten (Direkt)';
$lang['general_mark_qsl_tx_bureau'] = 'Markiere QSL gesendet (Büro)';
$lang['general_mark_qsl_tx_direct'] = 'Markiere QSL gesendet (Direkt)';

$lang['general_delete_qso'] = 'QSO Löschen';

$lang['general_total_distance'] = 'Entfernung';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Stationsprofil';

// ham radio terms
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Station';

$lang['gen_hamradio_call'] = 'Call';
$lang['gen_hamradio_callsign'] = 'Rufzeichen';
$lang['gen_hamradio_mode'] = 'Mode';
$lang['gen_hamradio_rst_sent'] = 'Gegeben';
$lang['gen_hamradio_rst_rcvd'] = 'Erhalten';
$lang['gen_hamradio_band'] = 'Band';
$lang['gen_hamradio_band_rx'] = 'Band (RX)';
$lang['gen_hamradio_frequency'] = 'Frequenz';
$lang['gen_hamradio_frequency_rx'] = 'Frequenz (RX)';
$lang['gen_hamradio_radio'] = 'Radio';
$lang['gen_hamradio_rsts'] = 'RST (S)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_exchange_sent_short'] = 'Exch (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Exch (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_locator'] = 'Locator';
$lang['gen_hamradio_transmit_power'] = 'Sendeleistung (W)';
$lang['gen_hamradio_propagation_mode'] = 'Propagation';


$lang['gen_hamradio_satellite_name'] = 'Satellit';
$lang['gen_hamradio_satellite_mode'] = 'Satellitenmodus';

$lang['gen_hamradio_logbook'] = 'Logbuch';

$lang['gen_hamradio_cq_zone'] = 'CQ Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Gelöschtes DXCC';
$lang['gen_hamradio_continent'] = 'Kontinent';
$lang['gen_hamradio_usa_state'] = 'USA-Staat';
$lang['gen_hamradio_county_reference'] = 'USA County';
$lang['gen_hamradio_iota_reference'] = 'IOTA Referenznummer';
$lang['gen_hamradio_sota_reference'] = 'SOTA Referenznummer';
$lang['gen_hamradio_wwff_reference'] = 'WWFF Referenznummer';
$lang['gen_hamradio_pota_reference'] = 'POTA Referenznummer';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'Staat';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Planquadrat';
$lang['gen_hamradio_operator'] = 'Operator';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';


// Dashboard Words
$lang['dashboard_you_have_had'] = 'Du hattest';
$lang['dashboard_qsos_today'] = 'QSOs heute!';
$lang['dashboard_qso_breakdown'] = 'QSO-Übersicht';
$lang['dashboard_countries_breakdown'] = 'Länderübersicht';

$lang['gen_from_date'] = 'Ab Datum';

$lang['gen_this_qso_was_confirmed_on'] = 'Dieses QSO wurde bestätigt am';

$lang['copy_to_clipboard'] = 'In die Zwischenablage kopieren';

$lang['africa'] = 'Afrika';
$lang['antarctica'] = 'Antarktis';
$lang['asia'] = 'Asien';
$lang['europe'] = 'Europa';
$lang['northamerica'] = 'Nord-Amerika';
$lang['oceania'] = 'Ozeanien';
$lang['southamerica'] = 'Süd-Amerika';

==> 2.4.11.tar.gz: cloudlog/application/language/german/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('Direkter Zugriff auf Skripte ist nicht erlaubt');

$lang['error_no_active_station_profile'] = 'Achtung: Du musst ein aktives Stationsprofil auswählen.';

$lang['notice_turn_the_radio_on'] = 'Du hast heute noch keine QSOs gemacht; Zeit, das Funkgerät einzuschalten!';

$lang['general_word_important'] = 'Wichtig';
$lang['general_word_warning'] = 'Warnung';
$lang['general_word_danger'] = 'GEFAHR';
$lang['general_word_maintenance'] = 'Wartung';
$lang['general_word_info'] = 'Info';
$lang['general_word_choose_file'] = 'Datei wählen';
$lang['general_word_next'] = 'Weiter';
$lang['general_word_previous'] = 'Zurück';
$lang['general_word_enabled'] = "Eingeschaltet";
$lang['general_word_disabled'] = "Ausgeschaltet";
$lang['general_word_export'] = "Exportieren";
$lang['general_word_import'] = "Importieren";

$lang['general_word_date'] = 'Datum';
$lang['general_word_time'] = 'Zeit';
$lang['general_word_datetime'] = 'Datum/Uhrzeit';
$lang['general_word_none'] = 'Nichts/Keine';
$lang['general_word_name'] = 'Name';
$lang['general_word_location'] = 'Standort';
$lang['general_word_comment'] = 'Kommentar';
$lang['general_word_general'] = 'Allgemeines';
$lang['general_word_satellite'] = 'Satellit';
$lang['general_word_satellite_short'] = 'Sat';
$lang['general_word_notes'] = 'Notizen';
$lang['general_word_country'] = 'Land';
$lang['general_word_city'] = 'Stadt';

$lang['general_word_total'] = 'Gesamt';
$lang['general_word_year'] = 'Jahr';
$lang['general_word_month'] = 'Monat';

$lang['general_word_worked'] = 'Gearbeitet';
$lang['general_word_confirmed'] = 'Bestätigt';
$lang['general_word_needed'] = 'Benötigt';

$lang['general_word_all'] = 'Alle';
$lang['general_word_no'] = 'Nein';
$lang['general_word_yes'] = 'Ja';
$lang['general_word_method'] = 'Methode';

$lang['general_word_sent'] = 'Gesendet';
$lang['general_word_received'] = 'Erhalten';
$lang['general_word_requested'] = 'Angefordert';
$lang['general_word_queued'] = 'In Warteschlange';
$lang['general_word_invalid_ignore'] = 'Ungültig (Ignorieren)';
$lang['general_word_qslcard'] = 'QSL Karte';
$lang['general_word_qslcard_management'] = 'QSL Verwaltung';
$lang['general_word_qslcards'] = 'QSL Karten';
$lang['general_word_qslcard_direct'] = 'Direkt';
$lang['general_word_qslcard_bureau'] = 'Büro';
$lang['general_word_qslcard_electronic'] = 'Elektronisch';
$lang['general_word_qslcard_manager'] = 'Manager';
$lang['general_word_qslcard_via'] = 'Via';
$lang['general_word_eqslcard'] = 'eQSL Karte';
$lang['general_word_eqslcards'] = 'eQSL Karten';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Daten';

$lang['general_edit_qso'] = 'QSO bearbeiten';
$lang['general_mark_qsl_rx_bureau'] = 'Markiere QSL erhalten (Büro)';
$lang['general_mark_qsl_rx_direct'] = 'Markiere QSL erhalten (Direkt)';
$lang['general_mark_qsl_rx_electronic'] = 'Markiere QSL erhalten (Elektronisch)';
$lang['general_mark_qsl_tx_bureau'] = 'Markiere QSL gesendet (Büro)';
$lang['general_mark_qsl_tx_direct'] = 'Markiere QSL gesendet (Direkt)';
$lang['general_mark_qsl_requested'] = 'Markiere QSL Karte als angefragt';
$lang['general_mark_qsl_requested_bureau'] = 'Markiere QSL Karte als angefragt (Büro)';
$lang['general_mark_qsl_requested_direct'] = 'Markiere QSL Karte als angefragt (Direkt)';
$lang['general_mark_qsl_not_required'] = 'Markiere QSL Karte als nicht notwendig';

$lang['general_delete_qso'] = 'QSO Löschen';
$lang['general_more_qso'] = 'Mehr QSOs';

$lang['general_lookup_qrz'] = 'Nachschlagen auf QRZ.com';
$lang['general_lookup_hamqth'] = 'Nachschlagen auf HamQTH';

$lang['general_total_distance'] = 'Entfernung';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Die max. Dateigrösse für Uploads beträgt ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Stationsprofil';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Station';

$lang['gen_hamradio_call'] = 'Call';
$lang['gen_hamradio_callsign'] = 'Rufzeichen';
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Mode';
$lang['gen_hamradio_rst_sent'] = 'Gegeben';
$lang['gen_hamradio_rst_rcvd'] = 'Erhalten';
$lang['gen_hamradio_band'] = 'Band';
$lang['gen_hamradio_bandgroup'] = "Bandgruppe";
$lang['gen_hamradio_band_rx'] = 'Band (RX)';
$lang['gen_hamradio_frequency'] = 'Frequenz';
$lang['gen_hamradio_frequency_rx'] = 'Frequenz (RX)';
$lang['gen_hamradio_radio'] = 'Funkgerät';
$lang['gen_hamradio_rsts'] = 'RST (S)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'Mein Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Exch (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Exch (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Locator';
$lang['gen_hamradio_transmit_power'] = 'Sendeleistung (W)';
$lang['gen_hamradio_propagation_mode'] = 'Propagation';

$lang['gen_hamradio_satellite_name'] = 'Satellit';
$lang['gen_hamradio_satellite_mode'] = 'Satellitenmodus';

$lang['gen_hamradio_logbook'] = 'Logbuch';

$lang['gen_hamradio_zones'] = 'Zonen';
$lang['gen_hamradio_cq_zone'] = 'CQ Zone';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Gelöschtes DXCC';
$lang['gen_hamradio_continent'] = 'Kontinent';
$lang['gen_hamradio_usa_state'] = 'US-Bundesstaat';
$lang['gen_hamradio_county_reference'] = 'US-County';
$lang['gen_hamradio_iota_reference'] = 'IOTA Referenznummer';
$lang['gen_hamradio_sota_reference'] = 'SOTA Referenznummer';
$lang['gen_hamradio_wwff_reference'] = 'WWFF Referenznummer';
$lang['gen_hamradio_pota_reference'] = 'POTA Referenznummer';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'Staat';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Planquadrat';
$lang['gen_hamradio_get_gridsquare'] = 'Orte mein Planquadrat';
$lang['gen_hamradio_distance'] = 'Entfernung';
$lang['gen_hamradio_operator'] = 'Operator';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq'] = "Wenn du deine CQ Zone nicht kennst <a href='https://zone-check.eu/?m=cq' target='_blank'>klicke hier</a> um sie herauszufinden!";
$lang['gen_find_zone_itu'] = "Wenn du deine ITU Zone nicht kennst <a href='https://zone-check.eu/?m=itu' target='_blank'>klicke hier</a> um sie herauszufinden!";

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Du hattest';
$lang['dashboard_qsos_today'] = 'QSOs heute!';
$lang['dashboard_qso_breakdown'] = 'QSO-Übersicht';
$lang['dashboard_countries_breakdown'] = 'Länderübersicht';

$lang['gen_from_date'] = 'Ab Datum';
$lang['gen_to_date'] = 'Bis Datum';

$lang['gen_this_qso_was_confirmed_on'] = 'Dieses QSO wurde bestätigt am';

$lang['error_no_logbook_found'] = 'Keine Logbücher gefunden. Du muss ein Stationslogbuch anlegen! Mach es hier:';

$lang['copy_to_clipboard'] = 'In die Zwischenablage kopieren';

$lang['africa'] = 'Afrika';
$lang['antarctica'] = 'Antarktis';
$lang['asia'] = 'Asien';
$lang['europe'] = 'Europa';
$lang['northamerica'] = 'Nordamerika';
$lang['oceania'] = 'Ozeanien';
$lang['southamerica'] = 'Südamerika';

$lang['gen_band_selection'] = 'Bandauswahl';
$lang['general_word_today'] = 'Heute';
